Changelog for Labware Domain Models
===================================


0.3.2 (2023-11-14)
------------------

- Added calculating/converting 2-letter row letters (for 1536 well plates)


0.3.1 (2020-12-24)
------------------

- Added calculating well index from rows and columns
- Added calculating well index from well name
